# Webservice Stash

A PyPI packages that supports all the necessary error codes, validation exception, common exceptions of a webservice. This PyPI package includes a method that establishes the connection to your firebase account.

## Installation

Run the following to install:

```python
pip install stash-service
```

## Usage

```python
import stash

# Your python code

```

MIT Licensed - 2021 : Britsa - britsa.tech@gmail.com

Contributors:
Maria Irudaya Regilan J